import os.path
from Selenium2Library import Selenium2Library
from robot.libraries import DateTime
from robot.libraries.BuiltIn import BuiltIn
from robot.libraries.Collections import Collections
from robot.libraries.OperatingSystem import OperatingSystem

__all__ = ('s2l', 'bi', 'dtl', 'osl', 'cl', 'get_artifacts_dir')


def get_artifacts_dir(delta_path=""):
    output_path = bi().get_variable_value("${EXECDIR}")
    output_path += "/Artifacts/"
    output_path += delta_path
    output_dir_normalized = os.path.dirname(os.path.abspath(os.path.normpath(output_path)))
    output_path_normalized = os.path.abspath(os.path.normpath(output_path))
    if not os.path.exists(output_dir_normalized):
        os.makedirs(output_dir_normalized)
    return output_path_normalized


def s2l():
    """

        :rtype : Selenium2Library
        """
    s2l_instance = BuiltIn().get_library_instance('Selenium2Library')
    assert isinstance(s2l_instance, Selenium2Library)
    return s2l_instance


def bi():
    """

        :rtype : BuiltIn
        """
    bi_instance = BuiltIn().get_library_instance('BuiltIn')
    assert isinstance(bi_instance, BuiltIn)
    return bi_instance


def dtl():
    """

        :rtype : DateTime
        """
    dt_instance = BuiltIn().get_library_instance('DateTime')
    assert isinstance(dt_instance, DateTime)
    return dt_instance


def osl():
    """

        :rtype : OperatingSystem
        """
    os_instance = BuiltIn().get_library_instance('OperatingSystem')
    assert isinstance(os_instance, OperatingSystem)
    return os_instance


def cl():
    """

        :rtype : Collections
        """
    c_instance = BuiltIn().get_library_instance('Collections')
    assert isinstance(c_instance, Collections)
    return c_instance



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2015 Cutting Edge QA

import csv
import os

from robot.libraries import DateTime

from robot_instances import *


class LoggerKeywordsExtension(object):
    OUTPUT_FILE = None

    def __init__(self, **kwargs):
        super(LoggerKeywordsExtension, self).__init__(**kwargs)
        self.OUTPUT_FILE = bi().get_variable_value("${EXECDIR}")

    @staticmethod
    def log_variable_to_file(name, comment="", output_file="variables.csv", level="INFO", html=False):
        log_file = get_artifacts_dir(output_file)

        fieldnames = ['Time', 'Test Case Name', 'Variable Name', 'Variable Value', 'Comment']
        current_time = DateTime.get_current_date(result_format="%Y.%m.%d %H:%M:%S")
        test_case_name = str(bi().get_variable_value("${TEST_NAME}"))
        suite_name = str(bi().get_variable_value("${SUITE_NAME}"))
        variable_value = name

        # TODO
        # get variable name is not working
        # variable_name = _Variables._get_var_name(bi(),str(name))
        # bi().get_variable_value("${" + variable_name + "}", "Missing!!!")

        with open(log_file, 'ab') as  csvfile:
            writer_csv = csv.writer(csvfile, dialect='excel')
            if os.stat(log_file).st_size < 10:
                writer_csv.writerow(fieldnames)
            writer_csv.writerow([current_time, suite_name + "." + test_case_name, name, variable_value, comment])

    def set_log_level_none(self):
        temp = bi()._context.output.set_log_level("None")
        bi().set_global_variable("${previous log level}", temp)

    def set_log_level_restore(self):
        temp = bi().get_variable_value("${previous log level}")
        bi()._context.output.set_log_level(temp)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2015 Cutting Edge QA


class CollectionsKeywordsExtension(object):
    def __int__(self, **kwargs):
        super(CollectionsKeywordsExtension, self).__int__(**kwargs)

    @staticmethod
    def create_dictionary_from_list(table):
        """

        :rtype : dict
        """
        return dict((x, 0) for x in table)

    @staticmethod
    def create_dictionary_from_two_lists(keys, values):
        """

        :rtype : dict
        """
        return dict(zip(keys, values))



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2015 Cutting Edge QA
import os

import time
import unicodecsv as csv
from robot.libraries import DateTime
from robot.utils import asserts

from robot_instances import *


class CsvKeywords(object):
    OUTPUT_FILE_CSV = "output.csv"

    def __init__(self, **kwargs):
        super(CsvKeywords, self).__init__(**kwargs)

    def csv_set_output_file(self, file_name=OUTPUT_FILE_CSV):
        self.OUTPUT_FILE_CSV = file_name

    def append_to_csv(self, filename, *values):
        with open(filename, 'ab') as csv_file:
            writer_csv = csv.writer(csv_file, dialect='excel')
            writer_csv.writerow(list(values))

    def csv_writer(self, *values):
        """
        Store to default file records in csv
        ${EXECDIR}/Artifacts/output.csv
        change file name using csv change output file
        """
        log_file = get_artifacts_dir() + "/" + self.OUTPUT_FILE_CSV
        self.append_to_csv(log_file, *values)

    def csv_writer_with_extra(self, *values):
        """
        Add extra params at begining
        1. time of exection
        2. suite + test cases name
        """
        test_case_name = str(bi().get_variable_value("${TEST_NAME}"))
        suite_name = str(bi().get_variable_value("${SUITE_NAME}"))
        extra_list = list(values)
        extra_list.insert(0, suite_name + test_case_name)
        self.csv_writer_with_time(*extra_list)

    def csv_writer_with_time(self, *values):
        current_time = DateTime.get_current_date(result_format="%Y.%m.%d %H:%M:%S")
        extra_list = list(values)
        extra_list.insert(0, current_time)
        self.csv_writer(*extra_list)

    def file_should_not_change(self, filename, time_in_sec="1", msg="File was modify during waiting time"):
        """
        Methods check mofifation date if date doesnt change after set time return true
        Best use with method Wait Until Keyword Succeeds
        """
        before = os.stat(filename).st_mtime
        time.sleep(float(time_in_sec))
        after = os.stat(filename).st_mtime
        asserts.assert_equal(before, after, msg, values=False)

    def append_to_file_at_beginning(self, path, content, encoding="UTF-8"):
        path = osl()._absnorm(path)
        parent = os.path.dirname(path)
        if not os.path.exists(parent):
            os.makedirs(parent)
        if not os.path.isfile(path):
            open(path, 'w').close()
        with file(path, 'r') as original: data = original.read()
        final_content = content + "\n" + data
        with file(path, 'w') as modified: modified.write(final_content.encode(encoding))
        osl()._link("Appended to file begin of file '%s'.", path)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2015 Cutting Edge QA
from TestToolsMK.csv_keywords import CsvKeywords
from TestToolsMK.logger_extension import LoggerKeywordsExtension
from TestToolsMK.collections_keywords import CollectionsKeywordsExtension
from TestToolsMK.image_magick_keywords import ImageMagickKeywords
from TestToolsMK.selenium_extentions import Selenium2LibraryExtensions
from TestToolsMK.google_sheets import GoogleSheets
from TestToolsMK.timers import TimerKeywords
import os

__version_file_path__ = os.path.join(os.path.dirname(__file__), 'VERSION')
__version__ = open(__version_file_path__, 'r').read().strip()


class TestToolsMK(GoogleSheets, Selenium2LibraryExtensions, TimerKeywords, CollectionsKeywordsExtension, ImageMagickKeywords, LoggerKeywordsExtension,
    CsvKeywords):
    ROBOT_LIBRARY_SCOPE = 'GLOBAL'
    ROBOT_LIBRARY_VERSION = __version__

    def __init__(self,**kwargs):
        print "TestToolsMK loaded"
        #super(TestToolsMK, self).__init__(**kwargs)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2015 Cutting Edge QA

import os
import robot
from robot.libraries.BuiltIn import BuiltIn
import robot.libraries.DateTime
from robot.libraries.DateTime import Time
from robot.libraries.DateTime import Date
from robot.api import logger
from datetime import datetime, timedelta
import time
import re
import datetime
from robot.version import get_version
from robot.utils import (elapsed_time_to_string, is_falsy, is_number, is_string, secs_to_timestr, timestr_to_secs, type_name, IRONPYTHON)


def get_current_time_for_timers():
    return datetime.datetime.now()


class TimerKeywords(Time, Date):
    TIMERS_DICTIONARY = {}

    def __int__(self, **kwargs):
        super(TimerKeywords, self).__int__(**kwargs)

    def timer_start(self, timer_name="Global"):
        current_time = get_current_time_for_timers()
        logger.info(current_time)
        if timer_name in self.TIMERS_DICTIONARY:
            error = "Timer with name \"%s\" already stated at %s" % (timer_name, self.TIMERS_DICTIONARY[timer_name].__str__())
            logger.warn(error)
        self.TIMERS_DICTIONARY[timer_name] = current_time
        msg = "Timer with name \"%s\" stated at %s" % (timer_name, self.TIMERS_DICTIONARY[timer_name].__str__())
        logger.info(msg)

    def timer_stop(self, timer_name="Global", result_format="number", exclude_millis="True"):
        current_time = get_current_time_for_timers()
        if timer_name not in self.TIMERS_DICTIONARY:
            message = "Time '%s' is not started." % timer_name
            raise AssertionError(message)
        else:
            delta = Time(current_time - self.TIMERS_DICTIONARY[timer_name]).convert(result_format, millis=is_falsy(exclude_millis))
            del self.TIMERS_DICTIONARY[timer_name]
            return delta

    def timer_restart(self, timer_name="Global", result_format="number", exclude_millis="True"):
        time_results = self.stop_timer(timer_name, result_format, exclude_millis)
        self.start_timer(timer_name)
        return time_results

    def timer_log(self, timer_name="Global", log_level="INFO", result_format="number", exclude_millis="True"):
        current_time = get_current_time_for_timers()
        if timer_name not in self.TIMERS_DICTIONARY:
            message = "Time '%s' is not started." % timer_name
            raise AssertionError(message)
        else:
            delta = Time(current_time - self.TIMERS_DICTIONARY[timer_name]).convert(result_format, millis=is_falsy(exclude_millis))
            msg = "Timer \"%s\" current results is %s" % (
                timer_name, Time(current_time - self.TIMERS_DICTIONARY[timer_name]).convert("verbose", millis=is_falsy(exclude_millis)))
            logger.write(msg, log_level)
            return delta

    def timer_should_be_lesser_then(self, expected_time, timer_name="Global"):
        if timer_name not in self.TIMERS_DICTIONARY:
            message = "Time '%s' is not started." % timer_name
            raise AssertionError(message)
        else:
            delta = get_current_time_for_timers() - self.TIMERS_DICTIONARY[timer_name]
            delta = Time._convert_time_to_seconds(self, delta)
            expected_time = Time._convert_time_to_seconds(self, expected_time)
            if delta > expected_time:
                message = "Timer '%s' is above expected time. Actual time %s > %s expected time " % (timer_name, delta, expected_time)
                raise AssertionError(message)
            return delta
